Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2941)

Unified Diff: components/autofill/core/browser/webdata/autofill_wallet_metadata_syncable_service.h

Issue 2626263005: [Autofill] Sync new wallet metadata fields through Chrome Sync. (Closed)
Patch Set: Add tests Created 3 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: components/autofill/core/browser/webdata/autofill_wallet_metadata_syncable_service.h
diff --git a/components/autofill/core/browser/webdata/autofill_wallet_metadata_syncable_service.h b/components/autofill/core/browser/webdata/autofill_wallet_metadata_syncable_service.h
index ed530f4f84bdacc3bc4f153fff6ca9903159b9ab..885b1d5bafa6c3861151d4ab1afcd98364588def 100644
--- a/components/autofill/core/browser/webdata/autofill_wallet_metadata_syncable_service.h
+++ b/components/autofill/core/browser/webdata/autofill_wallet_metadata_syncable_service.h
@@ -123,11 +123,25 @@ class AutofillWalletMetadataSyncableService
// is not present locally.
syncer::SyncMergeResult MergeData(const syncer::SyncDataList& sync_data);
// Sends updates to the sync server.
void AutofillDataModelChanged(
const std::string& server_id,
const sync_pb::WalletMetadataSpecifics::Type& type,
- const AutofillDataModel& local);
+ const AutofillProfile& local);
+
+ // Sends credit card updates to the sync server.
+ void AutofillDataModelChanged(
+ const std::string& server_id,
+ const sync_pb::WalletMetadataSpecifics::Type& type,
+ const CreditCard& local);
+
+ // Sends the autofill data model updates to the sync server if the local
+ // version is more recent. Used for both profiles and credit cards.
+ void SendUpdateIfMoreRecent(
+ const sync_pb::WalletMetadataSpecifics::Type& type,
+ const AutofillDataModel& local,
+ const syncer::SyncData& sync_data,
+ const sync_pb::WalletMetadataSpecifics& remote);
base::ThreadChecker thread_checker_;
AutofillWebDataBackend* web_data_backend_; // Weak ref.
@@ -123,11 +123,25 @@ class AutofillWalletMetadataSyncableService
// is not present locally.
syncer::SyncMergeResult MergeData(const syncer::SyncDataList& sync_data);
- // Sends updates to the sync server.
+ // Sends profile updates to the sync server.
void AutofillDataModelChanged(
const std::string& server_id,

Powered by Google App Engine
This is Rietveld 408576698